import React from 'react';
import styled from 'styled-components';

import { Button, Checkbox, Input, Switch, Tooltip } from '../lib';

import './index.css';

const Container = styled.div`
  margin: 0 auto;
  padding: 0 15px;
  max-width: 1200px;
  min-height: 100vh;

  h1 {
    margin-top: 10px;
  }

  label {
    margin-bottom: 6px;
  }

  section {
    margin-bottom: 20px;
  }

  section.buttons {
    button {
      margin: 0 8px;
    }

    button:first-of-type {
      margin: 0;
    }
  }

  section.inputs {
    input[type='text'] {
      max-width: 400px;
    }
  }

  .tooltip-container {
    display: flex;
  }
`;

const FlexRow = styled.div`
  display: flex;
  align-items: center;
  margin-bottom: 15px;
`;

const FlexCol = styled.div`
  display: flex;
  flex-direction: column;
  margin-bottom: 15px;
`;

function App() {
  return (
    <Container>
      <h1>Component Library</h1>
      <section className='buttons'>
        <h2>Buttons</h2>
        <FlexRow>
          <Button size='sm'>Primary</Button>
          <Button>Primary</Button>
          <Button size='lg'>Primary</Button>
          <Button size='lg' isLoading>
            Loading
          </Button>
          <Button size='lg' disabled>
            Disabled
          </Button>
        </FlexRow>
        <FlexRow>
          <Button color='secondary' size='sm'>
            Secondary
          </Button>
          <Button color='secondary'>Seconadry</Button>
          <Button color='secondary' size='lg'>
            Secondary
          </Button>
          <Button color='secondary' size='lg' disabled>
            Disabled
          </Button>
        </FlexRow>
      </section>

      <section className='inputs'>
        <h2>Inputs</h2>
        <FlexCol>
          <label>Text Input</label>
          <Input placeholder='Placeholder...' />
        </FlexCol>
        <FlexCol>
          <label htmlFor='checkbox'>Checkbox</label>
          <Checkbox id='checkbox' />
        </FlexCol>
        <FlexCol>
          <label>Switch</label>
          <Switch />
        </FlexCol>
      </section>

      <section className='tooltip'>
        <h2>Popover</h2>
        <div className='tooltip-container'>
          <Tooltip content='This is tooltip content. It will show on hover. Once again, this is a tooltip.'>
            <Button>Hover this for a tooltip.</Button>
          </Tooltip>
        </div>
      </section>
    </Container>
  );
}

export default App;
