import React from 'react';
import styled, { css } from 'styled-components';
import PropTypes from 'prop-types';

import { Spinner } from './common';

const propTypes = {
  children: PropTypes.node.isRequired,
  color: PropTypes.string,
  isLoading: PropTypes.bool,
  size: PropTypes.string
};

const defaultProps = {
  color: 'primary',
  size: 'md'
};

const sizeToFontMap = {
  sm: '12px',
  md: '14px',
  lg: '14px'
};

const sizeToPaddingMap = {
  sm: '2px 8px',
  md: '6px 12px',
  lg: '8px 20px'
};

const baseButton = css`
  display: flex;
  align-items: center;
  padding: ${props => sizeToPaddingMap[props.size]};
  border-radius: 1px;
  font-size: ${props => sizeToFontMap[props.size]};
  font-weight: 500;
  cursor: pointer;

  &:focus {
    outline: none;
  }

  &:disabled,
  &:disabled:hover {
    background-color: transparent;
    border: 1px solid #afb3ba;
    color: #afb3ba;
    box-shadow: none;
    cursor: no-drop;
  }
`;

const PrimaryButton = styled.button`
  ${baseButton};
  background-color: #0485cc;
  border: 1px solid #0485cc;
  color: #fff;

  &:hover {
    background-color: #0390de;
    border-color: #0390de;
    box-shadow: 0px 3px 4px rgba(0, 0, 0, 0.3);
  }

  &:active {
    background-color: #026089;
    border-color: #026089;
  }
`;

const SecondaryButton = styled.button`
  ${baseButton};
  background-color: #e7e8ea;
  border: 1px solid #e7e8ea;
  color: #2f3337;

  &:hover {
    box-shadow: 0px 1px 3px rgba(0, 0, 0, 0.2);
  }

  &:active {
    background-color: #ced1d5;
    border-color: #ced1d5;
  }
`;

const Button = ({ children, color, isLoading, ...rest }) => {
  if (color === 'secondary') {
    return (
      <SecondaryButton {...rest}>
        {children}
        {isLoading && <Spinner />}
      </SecondaryButton>
    );
  }
  return (
    <PrimaryButton {...rest}>
      {children}
      {isLoading && <Spinner />}
    </PrimaryButton>
  );
};

Button.propTypes = propTypes;
Button.defaultProps = defaultProps;

export default Button;
