import React, { useState } from 'react';
import styled from 'styled-components';
import PropTypes from 'prop-types';

import { FlexRow } from './common';

const propTypes = {
  size: PropTypes.string
};

const defaultProps = {
  size: 'md'
};

const sizeToDimensionsMap = {
  sm: { x: '22px', y: '12px', inner: '8px', translate: '11px' },
  md: { x: '40px', y: '24px', inner: '20px', translate: '18px' },
  lg: { x: '60px', y: '30px', inner: '26px', translate: '32px' }
};

const Container = styled(FlexRow)`
  cursor: pointer;
  .outer {
    display: flex;
    align-items: center;
    width: ${props => sizeToDimensionsMap[props.size].x};
    height: ${props => sizeToDimensionsMap[props.size].y};
    border: 1px solid #ced1d5;
    border-radius: 14px;
    background-color: ${props => (props.isToggled ? '#2DD055' : '#ced1d5')};
  }

  .inner {
    width: ${props => sizeToDimensionsMap[props.size].inner};
    height: ${props => sizeToDimensionsMap[props.size].inner};
    border-radius: 50%;
    background: #fff;
    transition: transform 0.2s ease-in;

    transform: ${props =>
      props.isToggled
        ? `translateX(${sizeToDimensionsMap[props.size].translate})`
        : 'tramslateX(0)'};
  }
`;

const Switch = props => {
  const [isToggled, setIsToggled] = useState(false);
  const handleClick = () => {
    setIsToggled(!isToggled);
  };
  return (
    <Container onClick={handleClick} isToggled={isToggled} {...props}>
      <div className='outer'>
        <div className='inner' />
      </div>
    </Container>
  );
};

Switch.propTypes = propTypes;
Switch.defaultProps = defaultProps;

export default Switch;
