import styled, { keyframes } from 'styled-components';

const FlexRow = styled.div`
  display: flex;
  align-items: center;
`;

const spin = keyframes`
    to {transform: rotate(360deg)}
`;

const Spinner = styled.span`
  position: relative;
  margin: 0 5px;
  width: 14px;
  height: 14px;

  &::before {
    content: '';
    position: absolute;
    left: 0;
    top: 0;
    width: 10px;
    height: 10px;
    border: 2px solid #fff;
    border-radius: 50%;
    border-top-color: transparent;
    border-bottom-color: transparent;
    animation: ${spin} 2s linear infinite;
  }
`;

const Tooltip = styled.div`
  position: relative;

  &::before {
    content: ${props => (props.content ? `'${props.content}'` : '')};
    position: absolute;
    left: calc(100% + 4px);
    top: 50%;
    padding: 10px 12px;
    width: 320px;
    border-radius: 1px;
    line-height: 1.5;
    background-color: #2f3337;
    color: #f9fafb;
    box-shadow: 0px 1px 3px rgba(0, 0, 0, 0.2);
    pointer-events: none;
    transform: translateY(-50%);
    opacity: 0;
  }

  &:hover::before {
    opacity: 1;
    transition: opacity 0.1s ease-in 0.1s;
  }
`;

export { FlexRow, Spinner, Tooltip };
